/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: PoolFactory.java 1970 2007-10-16 11:49:25Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.pool;

import org.ow2.easybeans.api.pool.PoolException;

/**
 * Allows to call specific methods for each implementation of the pool for each lifecycle on an object.
 * @param <InstanceType> the type of the object that are managed by the pool
 *        (could be EasyBeansSLSB, etc.)
 * @param <Clue> a clue which is given to match an instance in the pool
 * @author Florent Benoitt
 */
public interface PoolFactory<InstanceType, Clue> {


    /**
     * Creates an instance with the given hint.
     * @param clue a clue given by the Pool. Could be null.
     * @throws PoolException if instance cannot be created.
     * @return the created instance.
     */
    InstanceType create(Clue clue) throws PoolException;

    /**
     * Checks if the given object with the given clue is matching.
     * @param object given object against which the check should be done.
     * @param clue the object used as clue to check the matching.
     * @return true if it is matching, else false.
     */
    boolean isMatching(InstanceType object, Clue clue);


    /**
     * Validate an instance by giving some statistics.
     * @param object the instance to validate
     * @param stats some statistics to help in the validating process.
     * @return true if the element is valid, else false.
     */
    boolean validate(InstanceType object, PoolEntryStatistics stats);


    /**
     * Callback called when object is gonna be removed.
     * @param object that is being removed from the pool.
     */
    void remove(InstanceType object);

}
