/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: XMLMapping.java 1970 2007-10-16 11:49:25Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.xmlconfig.mapping;

import java.util.HashMap;
import java.util.Map;

/**
 * Mapping for a given name space.<br>
 * It contains all classes mapping.
 * @author Florent Benoit
 */
public class XMLMapping {

    /**
     * Association between class name (and alias) and the given class mapping.
     */
    private Map<String, ClassMapping> classMappings = null;

    /**
     * Default constructor.
     */
    public XMLMapping() {
        this.classMappings = new HashMap<String, ClassMapping>();
    }

    /**
     * Add a given class mapping object.
     * @param classMapping the given class.
     */
    public void addClassMapping(final ClassMapping classMapping) {
        classMappings.put(classMapping.getName(), classMapping);
        String alias = classMapping.getAlias();
        if (alias != null) {
            classMappings.put(alias, classMapping);
        }
    }

    /**
     * Gets the class mapping for the given class name.
     * @param className the given className.
     * @return the class mapping or null if not found.
     */
    public ClassMapping getClassMapping(final String className) {
        return classMappings.get(className);
    }

    /**
     * Returns a string representation of the object.
     * @return string representation
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        // classname
        sb.append(this.getClass().getName().substring(this.getClass().getPackage().getName().length() + 1));
        sb.append("[classMappings=");
        sb.append(classMappings);
        sb.append("]");

        return sb.toString();
    }
}
